@@ -32,15 +32,8 @@ class VirtualBoxTest(unittest.TestCase):
             self.box.snapshot('delete', name)
 
     def activate_snapshot(self, name):
-        if platform.system()=='Windows':
-            RETRIES_CNT = 5
-            for i in xrange(RETRIES_CNT):
-                if self.box.snapshot_exists(name):
-           	        break
-                else:
-                    time.sleep(1)
-        assert self.box.snapshot_exists(name), 'Snapshot "%s" does not exist' % name
         self.box.stop()
+        assert self.box.snapshot_exists(name), 'Snapshot "%s" does not exist' % name
         self.box.snapshot('restore', name)
         self.box.start(self.headless)
 
